@@ -3,7 +3,7 @@ use 5.008005;
 use strict;
 use warnings;
 
-our $VERSION = "0.08";
+our $VERSION = "0.09";
 
 1;
 __END__
@@ -31,6 +31,11 @@ protocol negotiation).
 
 It's alpha stage. I can run simple L<Dancer> PSGI app and it even work!
 
+Shuvgey pass all tests of L<h2spec tool|https://github.com/summerwind/h2spec>
+(version 1.01) for conformance with HTTP/2 implementation. Check it yourself:
+
+    $ h2spec -p 443 -h shuvgey.net -t
+
 =head1 NAMING
 
 There is a wellknown python non-blocking, single-threaded HTTP server Tornado.
